fn item_center_y(waves: &WaveData, item_ref: &DisplayedItemRef) -> Option<f32>Expand description
Returns the vertical center of a displayed waveform item in global coordinates.
fn item_center_y(waves: &WaveData, item_ref: &DisplayedItemRef) -> Option<f32>Returns the vertical center of a displayed waveform item in global coordinates.